/* f2c.h  --  Standard Fortran to C header file */

/**  barf  [ba:rf]  2.  "He suggested using FORTRAN, and everybody barfed."

	- From The Shogakukan DICTIONARY OF NEW ENGLISH (Second edition) */

#ifndef F2C_INCLUDE
#define F2C_INCLUDE

#include <stdint.h>

#if UINTPTR_MAX == UINT64_MAX
typedef int integer;
typedef int logical;
#else
typedef long int integer;
typedef long int logical;
#endif
typedef float real;
typedef double doublereal;
typedef struct { real r, i; } complex;
typedef struct { doublereal r, i; } doublecomplex;

#ifdef f2c_i2
typedef short ftnlen;
#else
#if UINTPTR_MAX == UINT64_MAX
typedef int ftnlen;
#else
typedef long int ftnlen;
#endif
#endif

typedef logical (*L_fp)();

#define VOID void

#endif
